;;; inf-guile-synch-voeb.el --- Example of using inf-guile.el

;; Copyright (C) 2005, 2007 Thien-Thi Nguyen
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this software; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Author: Thien-Thi Nguyen <ttn@gnu.org>

;;; Commentary:

;; This file sets up some transition handlers and defines a function
;; `inf-guile-synchronous-send/return'.  The "voeb" means "vector of output,
;; error-message and backtrace-message", which is what this function returns.

;;; Code:

(require 'inf-guile)

(define-inf-guile-transition t :enter-input-wait
  (lambda (proc old)
    (if (eq old :hello)
        (message "(Hello from %s!)" (capitalize (process-name proc)))
      (let ((out (process-get proc :output-so-far)))
        (process-put proc :output out)))))

(define-inf-guile-transition :sending-error :end-of-text
  (lambda (proc old)
    (process-put proc :error-message
                 (process-get proc :output-so-far))))

(define-inf-guile-transition :sending-backtrace :end-of-text
  (lambda (proc old)
    (process-put proc :backtrace-message
                 (process-get proc :output-so-far))))

(defun inf-guile-synchronous-send/return (proc s &rest args)
  (dolist (prop '(:output :error-message :backtrace-message))
    (process-put proc prop nil))
  (process-send-string proc (apply 'format (concat s "\n") args))
  (accept-process-output proc)
  (vector (process-get proc :output)
          (process-get proc :error-message)
          (process-get proc :backtrace-message)))

(provide 'inf-guile-synch-voeb)

;;; inf-guile-synch-voeb.el ends here
